/*
Example for Brushless_2 Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration PIC32 :
    
    MCU             : P32MX795F512L
    Dev. Board      : EasyPIC Fusion v7
    SW              : mikroC PRO for PIC32 v4.0.0

Description :

    This simple example demonstrates driving the motor with Brushless 2 click, 
    direction of motor is controled via MOTOR_DIR_PIN and speed is regulated with PWM.
    Board specific: Button press level PA to VCC, and PORTA pull down RA0 and RA4, 
    speed is controlled by pressing RA0 and direction is changed by pressing RA4.

*/
#include "stdint.h"

sbit MOTOR_DIR_PIN at RC1_bit;
sbit MOTOR_DIR_PIN_Direction at TRISC1_bit;

uint16_t const maxPwmDuty = 5000;
uint16_t currentDuty = 0;
uint8_t oldstate = 0;

void systemInit()
{
    AD1PCFG = 0xFFFF;
    JTAGEN_bit = 0;
    currentDuty = PWM_Init(5000, 1, 1, 2);
    PWM_Start(1);
    PWM_Set_Duty(currentDuty, 1);
    MOTOR_DIR_PIN_Direction = 0;
}

void Brushless_2_Init()
{
    MOTOR_DIR_PIN = 1;
}

void Brushless_2_Task()
{
    if (Button(&PORTA, 0, 1, 1))
    {
        currentDuty++;
        PWM_Set_Duty(currentDuty, 1);
        if (currentDuty > maxPwmDuty)      
            currentDuty = 0;              
        
    }
     
    if (Button(&PORTA, 4, 1, 1)) 
    {                                               
        oldstate = 1;                              
    }
    if (oldstate && Button(&PORTA, 4, 1, 0)) 
    {   
        MOTOR_DIR_PIN = ~MOTOR_DIR_PIN;                              
        oldstate = 0; 
    }                             
}

void main()
{
    systemInit();
    Brushless_2_Init();

    while( 1 )
    {
            Brushless_2_Task();
    }
}